package com.compdfkit.demo.annotation;

import android.graphics.Color;
import android.os.Bundle;
import android.view.View;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.content.ContextCompat;

import com.compdfkit.core.annotation.CPDFAnnotation;
import com.compdfkit.core.annotation.CPDFTextAnnotation;
import com.compdfkit.demo.annotation.databinding.ActivityMainBinding;
import com.compdfkit.tools.annotation.pdfproperties.pdfnote.CPDFtextAnnotAttachHelper;
import com.compdfkit.tools.annotation.pdfproperties.pdfnote.CPDFtextAnnotImpl;
import com.compdfkit.tools.common.utils.animation.CFillScreenManager;
import com.compdfkit.tools.common.utils.window.CPDFToolbarPopupMenu;
import com.compdfkit.tools.common.views.CPDFToolBar;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotationType;
import com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.manager.CAnnotStyleManager;
import com.compdfkit.tools.common.utils.task.CExtractAssetFileTask;
import com.compdfkit.tools.common.views.pdfbota.CPDFBOTA;
import com.compdfkit.tools.common.views.pdfbota.CPDFBotaDialogFragment;
import com.compdfkit.tools.common.views.pdfbota.CPDFBotaFragmentTabs;
import com.compdfkit.tools.viewer.pdfdisplaysettings.CPDFDisplaySettingDialogFragment;
import com.compdfkit.tools.viewer.pdfinfo.CPDFDocumentInfoDialogFragment;
import com.compdfkit.tools.viewer.pdfsearch.CSearchResultBottomSheetDialogFragment;
import com.compdfkit.ui.textsearch.ITextSearcher;

import java.util.ArrayList;

public class MainActivity extends AppCompatActivity {

    /**
     * assets folder pdf file
     */
    public static final String QUICK_START_GUIDE = "Quick Start Guide V2.4.0.pdf";

    private ActivityMainBinding binding;

    private CFillScreenManager screenManager = new CFillScreenManager();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        binding = ActivityMainBinding.inflate(getLayoutInflater());
        setContentView(binding.getRoot());
        binding.pdfView.setAllowAddAndEditAnnot(true);
        //Extract PDF files from the Android assets folder
        CExtractAssetFileTask.extract(this, QUICK_START_GUIDE, QUICK_START_GUIDE, (filePath) -> binding.pdfView.openPDF(filePath));
        initAnnotationAttributes();
        initListener();
        initSearchBar();
    }

    private void initListener() {
        screenManager.bindTopToolView(binding.flTool, binding.inkCtrlView);
        screenManager.bindBottomToolViewList(binding.annotationToolBar);
        screenManager.bindLeftToolViewList(binding.pdfView.indicatorView);
        screenManager.bindRightToolViewList(binding.pdfView.slideBar);

        binding.pdfView.addOnPDFFocusedTypeChangeListener(type -> {
            if (type != CPDFAnnotation.Type.INK){
                if (binding.inkCtrlView.getVisibility() == View.VISIBLE){
                    screenManager.removeAndHideToolView(binding.inkCtrlView);
                    screenManager.showFromBottom(binding.annotationToolBar, 200);
                    screenManager.bindBottomToolViewList(binding.annotationToolBar);
                }
            }
        });
        binding.pdfView.setOnTapMainDocAreaCallback(() -> {
            screenManager.fillScreenChange(binding.flTool.getVisibility() == View.VISIBLE);
        });


        binding.pdfToolBar.addMode(CPDFToolbarPopupMenu.PreviewMode.Annotation);
        binding.pdfToolBar.setPreviewModeChangeListener((mode, title) -> {
            if (mode == CPDFToolbarPopupMenu.PreviewMode.PDFView) {
                screenManager.hideFromBottom(binding.annotationToolBar, 200);
                screenManager.removeToolView(binding.annotationToolBar);
                screenManager.removeToolView(binding.inkCtrlView);
            } else {
                screenManager.bindBottomToolViewList(binding.annotationToolBar);
                screenManager.bindTopToolView(binding.inkCtrlView);
                screenManager.showFromBottom(binding.annotationToolBar, 200);
            }
            binding.pdfView.setAllowAddAndEditAnnot(mode != CPDFToolbarPopupMenu.PreviewMode.PDFView);
            binding.pdfView.resetAnnotationType();
        });

        binding.pdfToolBar.setSearchBtnClickListener(v -> {
            binding.pdfToolBar.setVisibility(View.GONE);
            binding.pdfSearchToolBar.setVisibility(View.VISIBLE);
        });
        binding.pdfToolBar.setThumbnailBtnClickListener(v -> {
            CPDFBotaDialogFragment dialogFragment = CPDFBotaDialogFragment.newInstance();
            dialogFragment.initWithPDFView(binding.pdfView);
            CPDFBotaFragmentTabs annotationTab = new CPDFBotaFragmentTabs(CPDFBOTA.THUMBNAIL, getString(R.string.tools_thumbnail));
            dialogFragment.setBotaDialogTab(annotationTab);
            dialogFragment.show(getSupportFragmentManager(), "ThumbnailList");
        });

        binding.pdfToolBar.setBoTaBtnClickListener(v -> {
            ArrayList<CPDFBotaFragmentTabs> tabs = new ArrayList<>();
            CPDFBotaFragmentTabs annotationTab = new CPDFBotaFragmentTabs(CPDFBOTA.ANNOTATION, getString(R.string.tools_menu_annotation));
            CPDFBotaFragmentTabs outlineTab = new CPDFBotaFragmentTabs(CPDFBOTA.OUTLINE, getString(R.string.tools_outline));
            CPDFBotaFragmentTabs bookmarkTab = new CPDFBotaFragmentTabs(CPDFBOTA.BOOKMARKS, getString(R.string.tools_bookmarks));
            if (binding.pdfToolBar.getMode() == CPDFToolbarPopupMenu.PreviewMode.PDFView) {
                tabs.add(outlineTab);
                tabs.add(bookmarkTab);
            } else {
                tabs.add(outlineTab);
                tabs.add(bookmarkTab);
                tabs.add(annotationTab);
                annotationTab.setDefaultSelect(true);
            }
            CPDFBotaDialogFragment dialogFragment = CPDFBotaDialogFragment.newInstance();
            dialogFragment.initWithPDFView(binding.pdfView);
            dialogFragment.setBotaDialogTabs(tabs);
            dialogFragment.show(getSupportFragmentManager(), "annotationList");
        });

        binding.pdfToolBar.setMoreMenuListener(menu -> {
            if (menu == CPDFToolBar.MoreMenu.DocumentInfo) {
                CPDFDocumentInfoDialogFragment infoDialogFragment = CPDFDocumentInfoDialogFragment.newInstance();
                infoDialogFragment.initWithPDFView(binding.pdfView);
                infoDialogFragment.show(getSupportFragmentManager(), "documentInfoDialogFragment");
            } else {
                CPDFDisplaySettingDialogFragment displaySettingDialogFragment = CPDFDisplaySettingDialogFragment.newInstance();
                displaySettingDialogFragment.initWithPDFView(binding.pdfView);
                displaySettingDialogFragment.show(getSupportFragmentManager(), "displaySettingsDialog");
            }
        });

        binding.annotationToolBar.initWithPDFView(binding.pdfView);
        binding.annotationToolBar.setFragmentManager(getSupportFragmentManager());
        binding.annotationToolBar.setAnnotationChangeListener(type -> {
            if (type == CAnnotationType.INK){
                screenManager.showFromTop(binding.inkCtrlView, 200);
                screenManager.bindTopToolView(binding.inkCtrlView);
                //
                screenManager.removeAndHideToolView(binding.annotationToolBar);
            }else {
                screenManager.showFromBottom(binding.annotationToolBar, 200);
                screenManager.bindBottomToolViewList(binding.annotationToolBar);
                screenManager.removeAndHideToolView(binding.inkCtrlView);
            }
        });

        binding.inkCtrlView.initWithPDFView(binding.pdfView);
    }

    private void initSearchBar() {
        binding.pdfSearchToolBar.initWithPDFView(binding.pdfView);
        binding.pdfSearchToolBar.onSearchQueryResults(list -> {
            CSearchResultBottomSheetDialogFragment searchResultDialog = new CSearchResultBottomSheetDialogFragment();
            searchResultDialog.show(getSupportFragmentManager(), "searchResultDialogFragment");
            searchResultDialog.setSearchTextInfos(list);
            searchResultDialog.setOnClickSearchItemListener(clickItem -> {
                binding.pdfView.getCPdfReaderView().setDisplayPageIndex(clickItem.page);
                binding.pdfView.getCPdfReaderView().getTextSearcher().searchBegin(clickItem.page, clickItem.textRangeIndex);
                searchResultDialog.dismiss();
            });
        });

        binding.pdfSearchToolBar.setExitSearchListener(() -> {
            ITextSearcher searcher = binding.pdfView.getCPdfReaderView().getTextSearcher();
            if (searcher != null) {
                searcher.cancelSearch();
                binding.pdfView.getCPdfReaderView().invalidateAllChildren();
            }
            binding.pdfToolBar.setVisibility(View.VISIBLE);
            binding.pdfSearchToolBar.setVisibility(View.GONE);
        });
    }

    private void initAnnotationAttributes() {
        int defaultColor = ContextCompat.getColor(this, R.color.tools_annotation_markup_default_color);
        new CAnnotStyleManager.Builder(binding.pdfView)
                .setColor(CAnnotationType.TEXT, defaultColor)
                .setMarkup(CAnnotationType.HIGHLIGHT, defaultColor, 255)
                .setMarkup(CAnnotationType.UNDERLINE, defaultColor, 255)
                .setMarkup(CAnnotationType.SQUIGGLY, defaultColor, 255)
                .setMarkup(CAnnotationType.STRIKEOUT, defaultColor, 255)
                .setShape(CAnnotationType.SQUARE, defaultColor, 255, Color.TRANSPARENT, 0, 10, null)
                .setShape(CAnnotationType.CIRCLE, defaultColor, 255, defaultColor, 255, 5, null)
                .setShape(CAnnotationType.LINE, defaultColor, 255, defaultColor, 255, 5, null)
                .setInkAttribute(defaultColor, 255, 10)
                .init();
        binding.pdfView.getCPdfReaderView().getAnnotImplRegistry().registAttachHelper(CPDFTextAnnotation.class, CPDFtextAnnotAttachHelper.class);
        binding.pdfView.getCPdfReaderView().getAnnotImplRegistry().registImpl(CPDFTextAnnotation.class, CPDFtextAnnotImpl.class);
    }
}