/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.annotation.pdfproperties;

import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.ViewModelProvider;
import androidx.viewpager2.widget.ViewPager2;

import com.compdfkit.tools.R;
import com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.adapter.CAnnotStyleFragmentAdapter;
import com.compdfkit.tools.common.utils.CWrapHeightPageChangeCallback;
import com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.viewmodel.CAnnotStyleViewModel;
import com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.CAnnotStyle;
import com.compdfkit.tools.common.utils.dialog.CDialogFragmentUtil;
import com.compdfkit.tools.common.views.pdfproperties.basic.CBasicPropertiesFragment;
import com.compdfkit.tools.common.views.pdfproperties.colorlist.CColorListView;
import com.compdfkit.tools.common.views.pdfproperties.colorpicker.CColorPickerFragment;
import com.compdfkit.tools.common.views.pdfproperties.colorpicker.widget.ColorPickerView;
import com.google.android.material.bottomsheet.BottomSheetBehavior;
import com.google.android.material.bottomsheet.BottomSheetDialogFragment;

import java.util.ArrayList;
import java.util.List;


public class CAnnotStyleDialogFragment extends BottomSheetDialogFragment implements CBasicPropertiesFragment.OnSwitchFragmentListener {

    private AppCompatImageView ivPreviousFragment;

    private AppCompatImageView ivClose;

    private AppCompatTextView tvTitle;

    private ViewPager2 viewPager;

    private CAnnotStyle style;

    private CAnnotStyleViewModel viewModel;

    private List<CAnnotStyle.OnAnnotStyleChangeListener> annotStyleChangeListenerList = new ArrayList<>();

    public static CAnnotStyleDialogFragment newInstance(CAnnotStyle style) {
        CAnnotStyleDialogFragment dialogFragment = new CAnnotStyleDialogFragment();
        dialogFragment.setStyle(style);
        return dialogFragment;
    }

    public void setStyle(CAnnotStyle style) {
        this.style = style;
    }

    public CAnnotStyle getStyle(){
        return viewModel != null ? viewModel.getStyle() : null;
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setStyle(STYLE_NORMAL, R.style.Tools_Base_Theme_BottomSheetDialogStyle);
        viewModel = new ViewModelProvider(getActivity()).get(CAnnotStyleViewModel.class);
        style.addStyleChangeListener(annotStyleChangeListenerList);
        viewModel.setStyle(style);
    }

    @Override
    public void onStart() {
        super.onStart();
        BottomSheetBehavior<View> behavior = BottomSheetBehavior.from((View) getView().getParent());
        behavior.setState(BottomSheetBehavior.STATE_EXPANDED);
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_annot_style_dialog_fragment, container, false);
        ivPreviousFragment = rootView.findViewById(R.id.iv_tool_bar_previous);
        ivClose = rootView.findViewById(R.id.iv_tool_bar_close);
        tvTitle = rootView.findViewById(R.id.tv_tool_bar_title);
        viewPager = rootView.findViewById(R.id.view_pager);
        return rootView;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        ivClose.setOnClickListener(v -> {
            dismiss();
        });
        ivPreviousFragment.setOnClickListener(v -> {
            previousFragment();
        });
        initViewPager();
    }

    private void initViewPager() {
        if (style != null) {
            CAnnotStyleFragmentAdapter adapter = new CAnnotStyleFragmentAdapter(style, getChildFragmentManager(), getLifecycle());
            adapter.setSwitchFragmentListener(this);
            viewPager.setAdapter(adapter);
            viewPager.setUserInputEnabled(false);
            viewPager.setOffscreenPageLimit(2);
            viewPager.registerOnPageChangeCallback(new CWrapHeightPageChangeCallback(viewPager, getChildFragmentManager()));
            viewPager.registerOnPageChangeCallback(new ViewPager2.OnPageChangeCallback() {
                @Override
                public void onPageSelected(int position) {
                    super.onPageSelected(position);
                    ivPreviousFragment.setVisibility(position != 0 ? View.VISIBLE : View.GONE);
                    ivClose.setVisibility(position == 0 ? View.VISIBLE : View.GONE);
                    tvTitle.setText(getString(adapter.getTitleByIndex(position)));
                }
            });
        }
    }

    @Override
    public void onSaveInstanceState(@NonNull Bundle outState) {
        super.onSaveInstanceState(outState);
    }

    @Override
    public void colorPickerFragment(int color, int opacity, ColorPickerView.COnColorChangeListener colorChangeListener) {
        viewPager.setCurrentItem(1);
        Fragment colorPickerFragment = getChildFragmentManager().findFragmentByTag("f" + 1);
        if (colorPickerFragment != null && colorPickerFragment instanceof CColorPickerFragment) {
            ((CColorPickerFragment) colorPickerFragment).initColor(color, opacity);
            ((CColorPickerFragment) colorPickerFragment).setColorPickerClickListener(colorChangeListener);
        }
    }

    @Override
    public void previousFragment() {
        viewPager.setCurrentItem(0);
    }

    public void addAnnotStyleChangeListener(CAnnotStyle.OnAnnotStyleChangeListener annotStyleChangeListener) {
        this.annotStyleChangeListenerList.add(annotStyleChangeListener);
    }


}
