/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.data;

import androidx.annotation.StringRes;

import com.compdfkit.tools.R;
import com.compdfkit.tools.annotation.pdfproperties.pdfannotstyle.CAnnotStyle;
import com.compdfkit.tools.annotation.pdfproperties.pdflnk.CInkStyleFragment;
import com.compdfkit.tools.annotation.pdfproperties.pdfmarkup.CMarkupStyleFragment;
import com.compdfkit.tools.annotation.pdfproperties.pdfnote.CNoteStyleFragment;
import com.compdfkit.tools.annotation.pdfproperties.pdfshape.CShapeStyleFragment;
import com.compdfkit.tools.common.views.pdfproperties.basic.CBasicPropertiesFragment;
import com.compdfkit.tools.common.views.pdfproperties.colorpicker.CColorPickerFragment;

import java.util.ArrayList;
import java.util.List;


public class CPropertiesFragmentDatas {

    public static List<CPropertiesFragmentBean> getPropertiesFragmentClass(CAnnotStyle style) {
        List<CPropertiesFragmentBean> list = new ArrayList<>();
        switch (style.getType()) {
            case STRIKEOUT:
            case HIGHLIGHT:
            case UNDERLINE:
            case SQUIGGLY:
                list.addAll(markupFragments(style));
                break;
            case TEXT:
                list.addAll(noteFragments(style));
                break;
            case INK:
                list.addAll(inkFragments(style));
                break;
            case SQUARE:
            case CIRCLE:
            case LINE:
            case ARROW:
                list.addAll(squareFragments(style));
                break;
            default:
               break;
        }
        return list;
    }

    public static <T extends CBasicPropertiesFragment> CBasicPropertiesFragment createPropertiesFragment(Class<T> tClass, CAnnotStyle style){
        try{
            return tClass.getDeclaredConstructor().newInstance();
        }catch (Exception e){
            return null;
        }
    }

    private static List<CPropertiesFragmentBean> markupFragments(CAnnotStyle style) {
        List<CPropertiesFragmentBean> list = new ArrayList<>();
        list.add(new CPropertiesFragmentBean(style.getAnnotTypeTitleResId(), CMarkupStyleFragment.class));
        list.add(new CPropertiesFragmentBean(R.string.tools_custom_color, CColorPickerFragment.class));
        return list;
    }

    private static List<CPropertiesFragmentBean> noteFragments(CAnnotStyle style){
        List<CPropertiesFragmentBean> list = new ArrayList<>();
        list.add(new CPropertiesFragmentBean(style.getAnnotTypeTitleResId(), CNoteStyleFragment.class));
        list.add(new CPropertiesFragmentBean(R.string.tools_custom_color, CColorPickerFragment.class));
        return list;
    }

    private static List<CPropertiesFragmentBean> inkFragments(CAnnotStyle style){
        List<CPropertiesFragmentBean> list = new ArrayList<>();
        list.add(new CPropertiesFragmentBean(style.getAnnotTypeTitleResId(), CInkStyleFragment.class));
        list.add(new CPropertiesFragmentBean(R.string.tools_custom_color, CColorPickerFragment.class));
        return list;
    }

    private static List<CPropertiesFragmentBean> squareFragments(CAnnotStyle style){
        List<CPropertiesFragmentBean> list = new ArrayList<>();
        list.add(new CPropertiesFragmentBean(style.getAnnotTypeTitleResId(), CShapeStyleFragment.class));
        list.add(new CPropertiesFragmentBean(R.string.tools_custom_color, CColorPickerFragment.class));
        return list;
    }

    public static class CPropertiesFragmentBean{

        private Class<? extends CBasicPropertiesFragment> fragmentClass;

        private int titleResId;

        public CPropertiesFragmentBean(@StringRes int titleRes, Class<? extends  CBasicPropertiesFragment> fragmentClass){
            this.titleResId = titleRes;
            this.fragmentClass = fragmentClass;
        }

        public Class<? extends CBasicPropertiesFragment> getFragmentClass() {
            return fragmentClass;
        }

        public void setFragmentClass(Class<? extends CBasicPropertiesFragment> claz) {
            this.fragmentClass = claz;
        }

        public int getTitleResId() {
            return titleResId;
        }

        public void setTitleResId(int titleResId) {
            this.titleResId = titleResId;
        }
    }
}
