/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.annotation.pdfproperties.pdflnk;

import android.content.Context;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.view.View;
import android.widget.FrameLayout;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatImageView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.pdfview.CPDFViewCtrl;
import com.compdfkit.ui.proxy.attach.IInkDrawCallback;
import com.compdfkit.ui.reader.CPDFReaderView;
import com.compdfkit.ui.reader.InkUndoRedoCallback;
import com.compdfkit.ui.reader.玖;

/**
 * Create a PDF Ink Control View that allows for controlling ink annotations with options for switching between erase,
 * undo, redo, delete, and confirm operations.
 *
 *
 */
public class CInkCtrlView extends FrameLayout implements View.OnClickListener {

    private AppCompatImageView ivEraser;

    private AppCompatImageView ivUndo;

    private AppCompatImageView ivRedo;

    private AppCompatImageView ivDelete;

    private AppCompatImageView ivConfirm;

    private CPDFViewCtrl pdfView;

    public CInkCtrlView(@NonNull Context context) {
        this(context, null);
    }

    public CInkCtrlView(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public CInkCtrlView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initView(context);
    }

    private void initView(Context context) {
        inflate(context, R.layout.tools_annot_properties_ink_ctrl_layout, this);
        ivEraser = findViewById(R.id.iv_ink_eraser);
        ivUndo = findViewById(R.id.iv_ink_undo);
        ivRedo = findViewById(R.id.iv_ink_redo);
        ivDelete = findViewById(R.id.iv_ink_clean);
        ivConfirm = findViewById(R.id.iv_ink_done);
        ivEraser.setOnClickListener(this);
        ivUndo.setOnClickListener(this);
        ivRedo.setOnClickListener(this);
        ivDelete.setOnClickListener(this);
        ivConfirm.setOnClickListener(this);

    }

    public void initWithPDFView(CPDFViewCtrl pdfView) {
        this.pdfView = pdfView;
        CPDFReaderView.TInkDrawHelper helper = pdfView.getCPdfReaderView().getInkDrawHelper();
        helper.setInkUndoRedoCallback((b, b1) -> {
            ivUndo.setEnabled(b);
            ivRedo.setEnabled(b1);
        });
        ivUndo.setEnabled(helper.canUndo());
        ivRedo.setEnabled(helper.canRedo());
    }

    @Override
    public void onClick(View v) {
        if (v.getId() == R.id.iv_ink_eraser) {
            if (pdfView != null) {
                if (ivEraser.isSelected()) {
                    ivEraser.setSelected(false);
                    pdfView.getCPdfReaderView().getInkDrawHelper().setMode(IInkDrawCallback.Mode.DRAW);
                } else {
                    ivEraser.setSelected(true);
                    pdfView.getCPdfReaderView().getInkDrawHelper().setMode(IInkDrawCallback.Mode.ERASE);
                }
            }
        } else if (v.getId() == R.id.iv_ink_undo) {
            if (pdfView != null) {
                pdfView.getCPdfReaderView().getInkDrawHelper().onUndo();
            }
        } else if (v.getId() == R.id.iv_ink_redo) {
            if (pdfView != null) {
                pdfView.getCPdfReaderView().getInkDrawHelper().onRedo();
            }
        } else if (v.getId() == R.id.iv_ink_clean) {
            if (pdfView != null) {
                pdfView.getCPdfReaderView().getInkDrawHelper().onClean();
                pdfView.getCPdfReaderView().getInkDrawHelper().setMode(IInkDrawCallback.Mode.DRAW);
            }
        } else if (v.getId() == R.id.iv_ink_done) {
            if (pdfView != null) {
                ivEraser.setSelected(false);
                pdfView.getCPdfReaderView().getInkDrawHelper().setMode(IInkDrawCallback.Mode.DRAW);
                pdfView.getCPdfReaderView().getInkDrawHelper().onSave();
                pdfView.resetAnnotationType();
            }
        } else {

        }
    }
}
