package com.compdfkit.tools.common.utils.window;


import android.content.Context;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;

import androidx.appcompat.widget.PopupMenu;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.CPDFToolBar;

import java.util.ArrayList;
import java.util.List;

public class CPDFToolbarPopupMenu implements PopupMenu.OnMenuItemClickListener {

    public enum PreviewMode {
        PDFView,
        Annotation,
        Form,
        Edit,
        PageEdit
    }

    private List<PreviewMode> previewModes = new ArrayList<>();

    private int samplePDFViewMenuId = View.generateViewId();

    private int annotViewMenuId = View.generateViewId();

    private int editMenuId = View.generateViewId();

    private int pageEditMenuId = View.generateViewId();

    private int formMenuId = View.generateViewId();

    private PreviewMode currentPreviewMode = PreviewMode.PDFView;

    private OnPreviewModeChangeListener changeListener;

    private PopupMenu popupMenu;

    private Context context;

    public CPDFToolbarPopupMenu(Context context,View anchor ){
        this.context = context;
        popupMenu = new PopupMenu(context,anchor );
        popupMenu.setOnMenuItemClickListener(this);
        addMode(currentPreviewMode);
    }

    public void addMode(PreviewMode mode){
        previewModes.add(mode);
        modifyPopupMenuStatus();
        changeMode(mode);
    }

    public int getMenuCount(){
        return previewModes.size();
    }

    public PreviewMode getMode(){
        return currentPreviewMode;
    }

    private void modifyPopupMenuStatus() {
        popupMenu.getMenu().clear();
        for (int i = 0; i < previewModes.size(); i++) {
            PreviewMode type = previewModes.get(i);
            int menuId;
            switch (type) {
                case Edit:
                    menuId = editMenuId;
                    break;
                case Form:
                    menuId = formMenuId;
                    break;
                case PageEdit:
                    menuId = pageEditMenuId;
                    break;
                case Annotation:
                    menuId = annotViewMenuId;
                    break;
                default:
                    menuId = samplePDFViewMenuId;
                    break;
            }
            popupMenu.getMenu().add(Menu.NONE, menuId, i, getTitleByMode(type));
        }
    }

    public String getTitleByMode(PreviewMode mode){
        switch (mode){
            case Annotation:
                return context.getString(R.string.tools_menu_annotation);
            case Edit:
                return context.getString(R.string.tools_menu_edit);
            case PageEdit:
                return context.getString(R.string.tools_menu_page_edit);
            case Form:
                return context.getString(R.string.tools_menu_form);
            default:
                return context.getString(R.string.tools_menu_pdfview);
        }
    }

    public void show() {
        if (popupMenu != null) {
            popupMenu.show();
        }
    }
    @Override
    public boolean onMenuItemClick(MenuItem item) {
        if (item.getItemId() == samplePDFViewMenuId) {
            changeMode(CPDFToolbarPopupMenu.PreviewMode.PDFView);
        } else if (item.getItemId() == annotViewMenuId) {
            changeMode(PreviewMode.Annotation);
        } else if (item.getItemId() == editMenuId) {
            changeMode(PreviewMode.Edit);
        } else if (item.getItemId() == pageEditMenuId) {
            changeMode(PreviewMode.PageEdit);
        } else if (item.getItemId() == formMenuId) {
            changeMode(PreviewMode.Form);
        }
        return false;
    }

    private void changeMode(PreviewMode mode) {
        currentPreviewMode = mode;
        if (changeListener != null) {
            changeListener.change(currentPreviewMode, getTitleByMode(currentPreviewMode));
        }
    }

    public void setMenuChangeListener(OnPreviewModeChangeListener changeListener) {
        this.changeListener = changeListener;
    }

    public interface OnPreviewModeChangeListener {
        void change(PreviewMode mode, String title);
    }
}
