/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfannotationbar.adapter;

import android.content.Context;
import android.content.res.ColorStateList;
import android.graphics.Color;
import android.view.ViewGroup;

import androidx.appcompat.widget.AppCompatImageView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotToolBean;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotationType;
import com.compdfkit.tools.common.utils.adapter.CBaseQuickAdapter;
import com.compdfkit.tools.common.utils.adapter.CBaseQuickViewHolder;

import java.util.List;


public class CPDFAnnotationToolListAdapter extends CBaseQuickAdapter<CAnnotToolBean, CBaseQuickViewHolder> {

    public static final String REFRESH_ITEM = "refresh_item";

    @Override
    protected CBaseQuickViewHolder onCreateViewHolder(Context context, ViewGroup parent, int viewType) {
        return new CBaseQuickViewHolder(R.layout.tools_annot_list_item, parent);
    }

    @Override
    protected void onBindViewHolder(CBaseQuickViewHolder holder, int position, CAnnotToolBean item) {
        holder.setImageResource(R.id.iv_annot_type, item.getIconResId());
        holder.setSelected(R.id.cl_annot_root, item.isSelect());
        refreshAnnotColor(holder, item);

    }

    @Override
    protected void onBindViewHolder(CBaseQuickViewHolder holder, int position, CAnnotToolBean item, List<Object> payloads) {
        if (payloads.isEmpty()) {
           super.onBindViewHolder(holder, position, item, payloads);
        } else {
            for (Object payload : payloads) {
                if (payload == REFRESH_ITEM) {
                    holder.setSelected(R.id.cl_annot_root, item.isSelect());
                    refreshAnnotColor(holder, item);
                }
            }
        }
    }

    private void refreshAnnotColor(CBaseQuickViewHolder holder, CAnnotToolBean item){
        switch (item.getType()){
            case HIGHLIGHT:
            case UNDERLINE:
            case SQUIGGLY:
            case INK:
            case STRIKEOUT:
                holder.setBackgroundColor(R.id.view_annot_bg, item.getBgColor());
                holder.setImageTintList(R.id.iv_annot_type, null);
                break;
            case TEXT:
                holder.setBackgroundColor(R.id.view_annot_bg, Color.TRANSPARENT);
                if (item.getBgColor() == Color.TRANSPARENT){
                    holder.setImageTintList(R.id.iv_annot_type, ColorStateList.valueOf(Color.BLACK));
                }else {
                    holder.setImageTintList(R.id.iv_annot_type, ColorStateList.valueOf(item.getBgColor()));
                }
                break;
            default:
                holder.setBackgroundColor(R.id.view_annot_bg, Color.TRANSPARENT);
                holder.setImageTintList(R.id.iv_annot_type, null);
                break;
        }
    }


    public void selectItem(int position) {
        for (int i = 0; i < list.size(); i++) {
            CAnnotToolBean item = list.get(i);
            if (i == position) {
                item.setSelect(!item.isSelect());
            } else {
                item.setSelect(false);
            }
            notifyItemChanged(i, REFRESH_ITEM);
        }
    }

    public void selectByType(CAnnotationType type){
        for (int i = 0; i < list.size(); i++) {
            CAnnotToolBean item = list.get(i);
            if (item.getType() == type) {
                item.setSelect(true);
            } else {
                item.setSelect(false);
            }
            notifyItemChanged(i, REFRESH_ITEM);
        }
    }

    public boolean hasSelectAnnotType(){
        for (int i = 0; i < list.size(); i++) {
            CAnnotToolBean item = list.get(i);
            if (item.isSelect()){
                return true;
            }
        }
        return false;
    }

    public CAnnotationType getCurrentAnnotType() {
        for (CAnnotToolBean cAnnotToolBean : list) {
            if (cAnnotToolBean.isSelect()){
                return cAnnotToolBean.getType();
            }
        }
        return CAnnotationType.UNKNOWN;
    }

    public void updateItemColor(CAnnotationType type, int color){
        for (int i = 0; i < list.size(); i++) {
            CAnnotToolBean item = list.get(i);
            if (item.getType() == type) {
                item.setBgColor(color);
                notifyItemChanged(i, REFRESH_ITEM);
                return;
            }
        }
    }
}
