/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.colorpicker;

import android.graphics.Color;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.pdfproperties.basic.CBasicPropertiesFragment;
import com.compdfkit.tools.common.views.pdfproperties.colorlist.CColorListView;
import com.compdfkit.tools.common.views.pdfproperties.colorpicker.widget.ColorPickerView;


public class CColorPickerFragment extends CBasicPropertiesFragment {

    public static CColorPickerFragment newInstance() {
        return new CColorPickerFragment();
    }

    private ColorPickerView colorPickerView;

    private int mSetColor = Color.BLACK;

    private int mSetColorOpacity = 255;

    private ColorPickerView.COnColorChangeListener colorChangeListener;

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_color_pick_fragment, container, false);
        colorPickerView = rootView.findViewById(R.id.color_picker_view);
        colorPickerView.initColor(mSetColor, mSetColorOpacity);
        colorPickerView.setColorPickerListener(new ColorPickerView.COnColorChangeListener() {
            @Override
            public void color(int color) {
                if (colorChangeListener != null) {
                    colorChangeListener.color(color);
                }
            }

            @Override
            public void opacity(int opacity) {
                if (colorChangeListener != null) {
                    colorChangeListener.opacity(opacity);
                }
            }
        });
        return rootView;
    }

    @Override
    public void onPause() {
        super.onPause();
        if (colorPickerView != null) {
            int color = viewModel.getStyle().getColor();
            int alpha = viewModel.getStyle().getColorOpacity();
            colorPickerView.initColor(color, alpha);
        }
    }

    public void initColor(int color, int opacity){
        this.mSetColor = color;
        this.mSetColorOpacity = opacity;
        if (colorPickerView != null) {
            colorPickerView.initColor(mSetColor, mSetColorOpacity);
        }
    }

    public void setColorPickerClickListener(ColorPickerView.COnColorChangeListener colorChangeListener) {
        this.colorChangeListener = colorChangeListener;
    }
}
