/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.colorpicker.widget;

import android.content.Context;
import android.graphics.Color;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.FrameLayout;

import androidx.annotation.ColorInt;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.compdfkit.tools.R;


public class ColorPickerView extends FrameLayout implements View.OnTouchListener {

    private ColorRectShowView mCurrentIndicatorColorView;

    private ColorRectShowView mLastColorShowView;

    private ColorRectView colorRectView;

    private ColorSliderView colorSliderView;

    private ColorAlphaSliderView colorOpacitySliderView;

    private int color = Color.BLACK;

    private int colorAlpha = 255;

    private int lastColor = Color.WHITE;

    private int lastColorAlpha = 255;

    private COnColorChangeListener colorPickerListener;

    public ColorPickerView(@NonNull Context context) {
        this(context, null);
    }

    public ColorPickerView(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public ColorPickerView(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initView(context);
    }

    private void initView(Context context){
        inflate(context, R.layout.tools_color_pick_view, this);
        mCurrentIndicatorColorView = findViewById(R.id.id_bottom_customize_cv_indicator);
        mLastColorShowView = findViewById(R.id.id_bottom_customize_cv_last);
        colorRectView = findViewById(R.id.id_bottom_customize_v_color_set);
        colorSliderView = findViewById(R.id.id_customize_color_slider);
        colorOpacitySliderView = findViewById(R.id.id_customize_color_alpha_slider);

        colorRectView.setColorSelectListener(color1 -> {
            mCurrentIndicatorColorView.changeColor(color1);
            colorSliderView.setBaseColor(color1);
            colorOpacitySliderView.setBaseColor(color1);
        });

        colorSliderView.setOnColorSelectListener(color1 -> {
            mCurrentIndicatorColorView.changeColor(color1);
        });

        colorOpacitySliderView.setColorOpacityChangeListener(opacity -> {
            mCurrentIndicatorColorView.changeAlpha(opacity);
            if (colorPickerListener != null) {
                colorPickerListener.opacity(opacity);
            }
        });
        colorRectView.setOnTouchListener(this::onTouch);
        colorSliderView.setOnTouchListener(this::onTouch);
//        colorOpacitySliderView.setOnTouchListener(this::onTouch);
    }

    public void initColor(@ColorInt int color, int colorAlpha){
        this.color = color;
        this.colorAlpha = colorAlpha;
        this.lastColor = color;
        this.lastColorAlpha = colorAlpha;
        updateColorView();
    }

    public void initColor(@ColorInt int color){
        this.color = color;
        this.lastColor = color;
        updateColorView();
    }

    public void initOpacity(int colorAlpha){
        this.colorAlpha = colorAlpha;
        this.lastColorAlpha = colorAlpha;
        updateColorView();
    }


    public void refreshColor(){
        initColor(this.color, this.colorAlpha);
    }


    private void updateColorView(){
        colorRectView.setColor(color);
        colorSliderView.setBaseColor(color);
        colorOpacitySliderView.setBaseColor(color);
        colorOpacitySliderView.setPercent(colorAlpha / 255F);
        mCurrentIndicatorColorView.changeColor(color);
        mCurrentIndicatorColorView.changeAlpha(colorAlpha);
        colorOpacitySliderView.invalidate();
        mLastColorShowView.changeAlpha(lastColorAlpha);
        mLastColorShowView.changeColor(lastColor);
    }

    @Override
    public boolean onTouch(View v, MotionEvent event) {
        if (event.getActionMasked() == MotionEvent.ACTION_UP){
            if (colorPickerListener != null) {
                colorPickerListener.color(mCurrentIndicatorColorView.getColor());
            }
        }
        return false;
    }

    public void setColorPickerListener(COnColorChangeListener colorPickerListener) {
        this.colorPickerListener = colorPickerListener;
    }

    public interface COnColorChangeListener{
        void color(int color);

        void opacity(int opacity);
    }
}
