/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.preview;


import android.content.Context;
import android.content.res.ColorStateList;
import android.util.AttributeSet;
import android.view.View;
import android.widget.FrameLayout;

import androidx.annotation.ColorInt;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.appcompat.widget.AppCompatTextView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.views.pdfannotationbar.bean.CAnnotationType;

class CAnnotMarkupPreviewView extends CBasicAnnotPreviewView {

    private AppCompatImageView ivMarkup;

    private View viewMarkupBg;

    public CAnnotMarkupPreviewView(@NonNull Context context) {
        super(context);
    }

    @Override
    protected void bindView() {
        inflate(getContext(), R.layout.tools_annot_preview_markup, this);
    }

    @Override
    protected void initView() {
        ivMarkup = findViewById(R.id.iv_preview_markup);
        viewMarkupBg = findViewById(R.id.view_markup_bg);
    }

    @Override
    public void setColor(int color) {
        viewMarkupBg.setBackgroundColor(color);
    }

    @Override
    public void setColorOpacity(int colorOpacity) {
        float percent = (float) colorOpacity / 255F;
        viewMarkupBg.setAlpha(percent);
    }

    public void setMarkupType(CAnnotationType type){
        switch(type){
            case HIGHLIGHT:
                ivMarkup.setImageResource(R.drawable.tools_ic_annotation_highlight);
                break;
            case UNDERLINE:
                ivMarkup.setImageResource(R.drawable.tools_ic_annotation_underline);
                break;
            case SQUIGGLY:
                ivMarkup.setImageResource(R.drawable.tools_ic_annotation_squiggly);
                break;
            case STRIKEOUT:
                ivMarkup.setImageResource(R.drawable.tools_ic_annotation_deleteline);
                break;
            default:break;
        }
    }

}
