/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.views.pdfproperties.sliderbar;


import android.content.Context;
import android.content.res.TypedArray;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.widget.FrameLayout;
import android.widget.SeekBar;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.StringRes;
import androidx.appcompat.widget.AppCompatSeekBar;
import androidx.appcompat.widget.AppCompatTextView;

import com.compdfkit.tools.R;

public class CBorderWidthSliderBar extends FrameLayout implements SeekBar.OnSeekBarChangeListener {

    private AppCompatTextView tvTitle;

    private AppCompatSeekBar seekBar;

    private boolean showTitle;

    private String title;

    private int sliderBarMaxValue;
    private int sliderBarMinValue;

    private boolean showValueTips = true;

    private OnProgressChangeListener changeListener;

    public CBorderWidthSliderBar(@NonNull Context context) {
        this(context, null);
    }

    public CBorderWidthSliderBar(@NonNull Context context, @Nullable AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public CBorderWidthSliderBar(@NonNull Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initView();
        initAttr(context, attrs);

    }

    private void initAttr(Context context, AttributeSet attrs) {
        TypedArray typedArray = context.obtainStyledAttributes(attrs, R.styleable.CBorderWidthSliderBar);
        if (typedArray != null) {
            showTitle = typedArray.getBoolean(R.styleable.CBorderWidthSliderBar_tools_show_title, true);
            title = typedArray.getString(R.styleable.CBorderWidthSliderBar_tools_title);
            sliderBarMaxValue = typedArray.getInt(R.styleable.CBorderWidthSliderBar_android_max, 100);
            sliderBarMinValue = typedArray.getInt(R.styleable.CBorderWidthSliderBar_slider_bar_min, 0);
            int progress = typedArray.getInt(R.styleable.CBorderWidthSliderBar_android_progress, 0);
            tvTitle.setVisibility(showTitle ? VISIBLE : GONE);
            if (!TextUtils.isEmpty(title)) {
                tvTitle.setText(title);
            }
            seekBar.setMax(sliderBarMaxValue);
            seekBar.setProgress(Math.max(0, progress));
            typedArray.recycle();
        }
    }

    private void initView() {
        inflate(getContext(), R.layout.tools_common_border_width_slider_bar, this);
        tvTitle = findViewById(R.id.tv_title);
        seekBar = findViewById(R.id.seek_bar);
        seekBar.setOnSeekBarChangeListener(this);
    }

    public void setProgress(int progress) {
        if (progress >sliderBarMaxValue){
            progress = sliderBarMaxValue;
        }
        this.seekBar.setProgress(progress);
    }

    public void setShowTitle(boolean show){
        this.showTitle = show;
        tvTitle.setVisibility(showTitle ? VISIBLE : GONE);
    }

    public void setTitle(String title){
        this.title = title;
        tvTitle.setText(title);
    }

    public void setTitle(@StringRes int stringResId){
        this.title = getContext().getString(stringResId);
        tvTitle.setText(title);
    }

    private void updateSeekBarValue(int value) {
        int v = Math.max(sliderBarMinValue, value);
        int currentPercentage = Math.round((float) v / (float) sliderBarMaxValue * 100F);
        if (changeListener != null) {
            changeListener.changed(v, currentPercentage);
        }
    }

    public void setChangeListener(OnProgressChangeListener changeListener) {
        this.changeListener = changeListener;
    }

    @Override
    public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
        if (fromUser){
            updateSeekBarValue(progress);
        }
    }

    @Override
    public void onStartTrackingTouch(SeekBar seekBar) {

    }

    @Override
    public void onStopTrackingTouch(SeekBar seekBar) {

    }

    public interface OnProgressChangeListener {
        void changed(int progress, int percentageValue);
    }
}
