/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.viewer.pdfbookmark;


import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.core.common.CPDFDate;
import com.compdfkit.core.document.CPDFBookmark;
import com.compdfkit.core.utils.TTimeUtil;
import com.compdfkit.tools.R;
import com.compdfkit.tools.common.interfaces.COnSetPDFDisplayPageIndexListener;
import com.compdfkit.tools.common.views.pdfview.CPDFViewCtrl;
import com.compdfkit.tools.viewer.pdfbookmark.adapter.CPDFBookmarkListAdapter;
import com.compdfkit.tools.viewer.pdfbookmark.dialog.CEditBookmarkDialog;
import com.google.android.material.floatingactionbutton.FloatingActionButton;

import java.util.ArrayList;
import java.util.List;

public class CPDFBookmarkFragment extends Fragment {

    private RecyclerView rvPdfBookmark;

    private FloatingActionButton btnAddBookmark;

    private CPDFViewCtrl pdfView;

    private COnSetPDFDisplayPageIndexListener displayPageIndexListener;

    public static CPDFBookmarkFragment newInstance() {
        return new CPDFBookmarkFragment();
    }

    public void initWithPDFView(CPDFViewCtrl pdfView) {
        this.pdfView = pdfView;
    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_bookmark_list_fragment, container, false);
        rvPdfBookmark = rootView.findViewById(R.id.rv_pdf_bookmark);
        btnAddBookmark = rootView.findViewById(R.id.flbtn_add_bookmark);
        return rootView;
    }


    public void setPDFDisplayPageIndexListener(COnSetPDFDisplayPageIndexListener displayPageIndexListener) {
        this.displayPageIndexListener = displayPageIndexListener;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        CPDFBookmarkListAdapter bookmarkListAdapter = new CPDFBookmarkListAdapter();
        bookmarkListAdapter.submitList(getBookmarkList());
        bookmarkListAdapter.setDisplayPageIndexListener(displayPageIndexListener);
        bookmarkListAdapter.setDeleteBookmarkClickListener((bookmark, index) -> {
            if (pdfView != null) {
                pdfView.getCPdfReaderView().getPDFDocument().removeBookmark(bookmark.getPageIndex());
            }
            bookmarkListAdapter.submitList(getBookmarkList());
        });

        bookmarkListAdapter.setEditBookmarkClickListener((bookmark, index) -> {
            CEditBookmarkDialog editBookmarkDialog = CEditBookmarkDialog.newInstance(bookmark.getTitle());
            editBookmarkDialog.setEditBookmarkListener(title -> {
                if (pdfView != null) {
                    pdfView.getCPdfReaderView().getPDFDocument().getBookmarks()
                            .get(index)
                            .setTitle(title);
                    bookmarkListAdapter.updateBookmarkItem(index);
                }
                editBookmarkDialog.dismiss();
            });
            editBookmarkDialog.show(getChildFragmentManager(), "editBookmarkDialog");
        });

        rvPdfBookmark.setLayoutManager(new LinearLayoutManager(getContext()));
        rvPdfBookmark.setAdapter(bookmarkListAdapter);
        btnAddBookmark.setOnClickListener(v -> {
            CEditBookmarkDialog editBookmarkDialog = CEditBookmarkDialog.newInstance("");
            editBookmarkDialog.setEditBookmarkListener(title -> {
                if (pdfView != null) {
                    int pageIndex = pdfView.currentPageIndex;
                    pdfView.getCPdfReaderView().getPDFDocument().addBookmark(new CPDFBookmark(
                            pageIndex, title, CPDFDate.toStandardDate(TTimeUtil.getCurrentDate())
                    ));
                    bookmarkListAdapter.submitList(getBookmarkList());
                }
                editBookmarkDialog.dismiss();
            });
            editBookmarkDialog.show(getChildFragmentManager(), "editBookmarkDialog");
        });
    }

    private List<CPDFBookmark> getBookmarkList() {
        if (pdfView != null) {
            List<CPDFBookmark> list = pdfView.getCPdfReaderView().getPDFDocument().getBookmarks();
            return new ArrayList<>(list);
        } else {
            return new ArrayList<>();
        }
    }
}
