package com.compdfkit.tools.viewer.pdfbookmark.adapter;


import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.appcompat.widget.PopupMenu;
import androidx.recyclerview.widget.DiffUtil;
import androidx.recyclerview.widget.ListAdapter;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.core.document.CPDFBookmark;
import com.compdfkit.tools.R;
import com.compdfkit.tools.common.interfaces.COnSetPDFDisplayPageIndexListener;

import java.util.List;

public class CPDFBookmarkListAdapter extends ListAdapter<CPDFBookmark, CPDFBookmarkListAdapter.CPDFBookmarkItemViewHolder> {

    public static final String REFRESH_ITEM = "refresh_item";

    private COnSetPDFDisplayPageIndexListener displayPageIndexListener;

    private OnBookmarkCallback editBookmarkClickListener;

    private OnBookmarkCallback deleteBookmarkClickListener;

    public CPDFBookmarkListAdapter() {
        super(new BookmarkDiffCallback());
    }

    @NonNull
    @Override
    public CPDFBookmarkItemViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        return new CPDFBookmarkItemViewHolder(LayoutInflater.from(parent.getContext()).inflate(R.layout.tools_bookmark_list_item, parent, false));
    }

    @Override
    public void onBindViewHolder(@NonNull CPDFBookmarkItemViewHolder holder, int position, @NonNull List<Object> payloads) {
        if (payloads.isEmpty()) {
            super.onBindViewHolder(holder, position, payloads);
        } else {
            for (Object payload : payloads) {
                if (payload == REFRESH_ITEM) {
                    CPDFBookmark item = getCurrentList().get(position);
                    holder.tvTitle.setText(item.getTitle());
                }
            }
        }
    }

    @Override
    public void onBindViewHolder(@NonNull CPDFBookmarkItemViewHolder holder, int position) {
        CPDFBookmark bookmark = getItem(holder.getAdapterPosition());
        holder.tvTitle.setText(bookmark.getTitle());
        holder.tvPageIndex.setText(holder.itemView.getContext().getString(R.string.tools_page) + " " + (bookmark.getPageIndex() + 1));
        holder.ivMore.setOnClickListener(v -> {
            PopupMenu popupMenu = new PopupMenu(v.getContext(), v);
            popupMenu.setOnMenuItemClickListener(item -> {
                if (item.getItemId() == R.id.tools_bookmark_edit) {
                    if (editBookmarkClickListener != null) {
                        editBookmarkClickListener.bookmark(bookmark, holder.getAdapterPosition());
                    }
                } else if (item.getItemId() == R.id.tools_bookmark_delete) {
                    if (deleteBookmarkClickListener != null) {
                        deleteBookmarkClickListener.bookmark(bookmark, holder.getAdapterPosition());
                    }
                }
                return true;
            });
            popupMenu.inflate(R.menu.tools_bookmark_list_item_more_menu);
            popupMenu.show();
        });
        holder.itemView.setOnClickListener(v -> {
            if (displayPageIndexListener != null) {
                displayPageIndexListener.displayPage(bookmark.getPageIndex());
            }
        });
    }

    static class CPDFBookmarkItemViewHolder extends RecyclerView.ViewHolder {

        private AppCompatTextView tvTitle;

        private AppCompatTextView tvPageIndex;

        private AppCompatImageView ivMore;

        public CPDFBookmarkItemViewHolder(@NonNull View itemView) {
            super(itemView);
            tvTitle = itemView.findViewById(R.id.tv_bookmark_title);
            tvPageIndex = itemView.findViewById(R.id.tv_bookmark_page);
            ivMore = itemView.findViewById(R.id.iv_bookmark_more);
        }
    }

    public void setDisplayPageIndexListener(COnSetPDFDisplayPageIndexListener displayPageIndexListener) {
        this.displayPageIndexListener = displayPageIndexListener;
    }

    public void setDeleteBookmarkClickListener(OnBookmarkCallback deleteBookmarkClickListener) {
        this.deleteBookmarkClickListener = deleteBookmarkClickListener;
    }

    public void setEditBookmarkClickListener(OnBookmarkCallback bookmarkClickListener) {
        this.editBookmarkClickListener = bookmarkClickListener;
    }

    public interface OnBookmarkCallback {
        void bookmark(CPDFBookmark bookmark, int index);
    }

    static class BookmarkDiffCallback extends DiffUtil.ItemCallback<CPDFBookmark> {
        @Override
        public boolean areItemsTheSame(@NonNull CPDFBookmark oldItem, @NonNull CPDFBookmark newItem) {
            return oldItem.toString().equals(newItem.toString());
        }

        @Override
        public boolean areContentsTheSame(@NonNull CPDFBookmark oldItem, @NonNull CPDFBookmark newItem) {
            return oldItem == newItem;
        }
    }

    public void updateBookmarkItem(int index) {
        notifyItemChanged(index, REFRESH_ITEM);
    }
}
