/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.viewer.pdfbookmark.dialog;

import android.app.Dialog;
import android.content.Context;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.widget.AppCompatEditText;
import androidx.fragment.app.DialogFragment;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.utils.viewutils.CViewUtils;


public class CEditBookmarkDialog extends DialogFragment {

    private static final String EXTRA_BOOKMARK_TITLE = "extra_bookmark_title";

    private AppCompatEditText etBookmark;

    private Button btnCancel;

    private Button btnAdd;

    private OnEditBookmarkListener editBookmarkListener;

    public static CEditBookmarkDialog newInstance(String title) {
        CEditBookmarkDialog dialog = new CEditBookmarkDialog();
        Bundle bundle = new Bundle();
        bundle.putString(EXTRA_BOOKMARK_TITLE, title);
        dialog.setArguments(bundle);
        return dialog;
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
//        setStyle(DialogFragment.STYLE_NO_TITLE, R.style.tools_dialog_fragment_style);

    }

    @Nullable
    @Override
    public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View rootView = inflater.inflate(R.layout.tools_bookmark_input_dialog, container, false);
        etBookmark = rootView.findViewById(R.id.et_bookmark);
        btnCancel = rootView.findViewById(R.id.btn_cancel);
        btnAdd = rootView.findViewById(R.id.btn_add);
        return rootView;
    }

    @Override
    public void onViewCreated(@NonNull View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        if (getArguments() != null) {
            String defaultTitle = getArguments().getString(EXTRA_BOOKMARK_TITLE);
            etBookmark.setText(defaultTitle);
            etBookmark.setSelection(defaultTitle.length());
        }
        CViewUtils.showKeyboard(etBookmark);
        btnCancel.setOnClickListener(v -> dismiss());
        btnAdd.setOnClickListener(v -> {
            String title = etBookmark.getText().toString().trim();
            if (!TextUtils.isEmpty(title)) {
                if (editBookmarkListener != null) {
                    editBookmarkListener.edit(title);
                }
            }
        });
    }

    @Override
    public void dismiss() {
        CViewUtils.hideKeyboard(getDialog());
        super.dismiss();
    }

    @NonNull
    @Override
    public Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        return new Dialog(getActivity(), getTheme()) {
            @Override public void cancel() {
                if (getActivity() != null && getView() != null) {
                    InputMethodManager imm = (InputMethodManager) getActivity().getSystemService(Context.INPUT_METHOD_SERVICE);
                    imm.hideSoftInputFromWindow(getView().getWindowToken(), 0);
                }
                super.cancel();
            }
        };
    }

    public void setEditBookmarkListener(OnEditBookmarkListener editBookmarkListener) {
        this.editBookmarkListener = editBookmarkListener;
    }

    public interface OnEditBookmarkListener {
        void edit(String title);
    }
}
